==> ejc-zdsmaterialb-api-3.0.0-20241013.122636-25-sources.jar: com/ejianc/business/zdsmaterial/erp/vo/BrandVO.java <==
package com.ejianc.business.zdsmaterial.erp.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.util.Date;

/**
 * @author CJ
 * @Description:
 * @date 2023/12/11 16:32
 */
public class BrandVO extends BaseVO {

    private static final long serialVersionUID = 2006537660437310621L;

    private String brandName; //品牌名称
    private String sourceId; //ERP品牌主键
    private Integer enabled; //品牌停启用:0-停用，1-启用
    private Integer sequence; //序号
    private String memo; //备注

    private String label; //标签

    private String sourceType;//数据来源：1-新增，2-同步第三方
    private String pushErpFlag; //推送ERP标识：0-待推送，1-已推送，2-推送失败
    private Long approveUserId; //审核人id
    private String approveUserSid;//审核人sid
    private String approveUserName; //审核人名称
    private String approveUserCode;//审核人账号
    private Date effectDate; //生效日期
    private Long applyId; //来源申请单Id
    private Long applyDetailId; //来源申请单子表Id

    private Long relationId;//关系Id
    private String materialTypeId;//分类Id
    private String materialTypeCode;//分类编码
    private String materialTypeName;//分类名称

    private Long brandId;//品牌Id -- 品牌库使用

    public Long getBrandId() {
        return brandId;
    }

    public void setBrandId(Long brandId) {
        this.brandId = brandId;
    }

    public String getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(String materialTypeId) {
        this.materialTypeId = materialTypeId;
    }

    public String getMaterialTypeCode() {
        return materialTypeCode;
    }

    public void setMaterialTypeCode(String materialTypeCode) {
        this.materialTypeCode = materialTypeCode;
    }

    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }

    public Long getRelationId() {
        return relationId;
    }

    public void setRelationId(Long relationId) {
        this.relationId = relationId;
    }

    public String getLabel() {
        return label;
    }

    public void setLabel(String label) {
        this.label = label;
    }

    public String getSourceType() {
        return sourceType;
    }

    public void setSourceType(String sourceType) {
        this.sourceType = sourceType;
    }

    public String getPushErpFlag() {
        return pushErpFlag;
    }

    public void setPushErpFlag(String pushErpFlag) {
        this.pushErpFlag = pushErpFlag;
    }

    public Long getApproveUserId() {
        return approveUserId;
    }

    public void setApproveUserId(Long approveUserId) {
        this.approveUserId = approveUserId;
    }

    public String getApproveUserSid() {
        return approveUserSid;
    }

    public void setApproveUserSid(String approveUserSid) {
        this.approveUserSid = approveUserSid;
    }

    public String getApproveUserName() {
        return approveUserName;
    }

    public void setApproveUserName(String approveUserName) {
        this.approveUserName = approveUserName;
    }

    public String getApproveUserCode() {
        return approveUserCode;
    }

    public void setApproveUserCode(String approveUserCode) {
        this.approveUserCode = approveUserCode;
    }

    public Date getEffectDate() {
        return effectDate;
    }

    public void setEffectDate(Date effectDate) {
        this.effectDate = effectDate;
    }

    public Long getApplyId() {
        return applyId;
    }

    public void setApplyId(Long applyId) {
        this.applyId = applyId;
    }

    public Long getApplyDetailId() {
        return applyDetailId;
    }

    public void setApplyDetailId(Long applyDetailId) {
        this.applyDetailId = applyDetailId;
    }

    public String getBrandName() {
        return brandName;
    }

    public void setBrandName(String brandName) {
        this.brandName = brandName;
    }

    public String getSourceId() {
        return sourceId;
    }

    public void setSourceId(String sourceId) {
        this.sourceId = sourceId;
    }

    public Integer getEnabled() {
        return enabled;
    }

    public void setEnabled(Integer enabled) {
        this.enabled = enabled;
    }

    public Integer getSequence() {
        return sequence;
    }

    public void setSequence(Integer sequence) {
        this.sequence = sequence;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
}

==> ejc-zdsmaterialb-api-3.0.0-20251206.092311-104-sources.jar: com/ejianc/business/zdsmaterial/erp/vo/BrandVO.java <==
package com.ejianc.business.zdsmaterial.erp.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.util.Date;

/**
 * @author CJ
 * @Description:
 * @date 2023/12/11 16:32
 */
public class BrandVO extends BaseVO {

    private static final long serialVersionUID = 2006537660437310621L;

    private String brandName; //品牌名称
    private String sourceId; //ERP品牌主键
    private Integer enabled; //品牌停启用:0-停用，1-启用
    private Integer relationEnabled; //品牌停启用
    private Integer sequence; //序号
    private String memo; //备注

    private String label; //标签

    private String sourceType;//数据来源：1-新增，2-同步第三方
    private String pushErpFlag; //推送ERP标识：0-待推送，1-已推送，2-推送失败
    private Long approveUserId; //审核人id
    private String approveUserSid;//审核人sid
    private String approveUserName; //审核人名称
    private String approveUserCode;//审核人账号
    private Date effectDate; //生效日期
    private Long applyId; //来源申请单Id
    private Long applyDetailId; //来源申请单子表Id

    private Long relationId;//关系Id
    private String materialTypeId;//分类Id
    private String materialTypeCode;//分类编码
    private String materialTypeName;//分类名称

    private Long brandId;//品牌Id -- 品牌库使用

    public Integer getRelationEnabled() {
        return relationEnabled;
    }

    public void setRelationEnabled(Integer relationEnabled) {
        this.relationEnabled = relationEnabled;
    }

    public Long getBrandId() {
        return brandId;
    }

    public void setBrandId(Long brandId) {
        this.brandId = brandId;
    }

    public String getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(String materialTypeId) {
        this.materialTypeId = materialTypeId;
    }

    public String getMaterialTypeCode() {
        return materialTypeCode;
    }

    public void setMaterialTypeCode(String materialTypeCode) {
        this.materialTypeCode = materialTypeCode;
    }

    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }

    public Long getRelationId() {
        return relationId;
    }

    public void setRelationId(Long relationId) {
        this.relationId = relationId;
    }

    public String getLabel() {
        return label;
    }

    public void setLabel(String label) {
        this.label = label;
    }

    public String getSourceType() {
        return sourceType;
    }

    public void setSourceType(String sourceType) {
        this.sourceType = sourceType;
    }

    public String getPushErpFlag() {
        return pushErpFlag;
    }

    public void setPushErpFlag(String pushErpFlag) {
        this.pushErpFlag = pushErpFlag;
    }

    public Long getApproveUserId() {
        return approveUserId;
    }

    public void setApproveUserId(Long approveUserId) {
        this.approveUserId = approveUserId;
    }

    public String getApproveUserSid() {
        return approveUserSid;
    }

    public void setApproveUserSid(String approveUserSid) {
        this.approveUserSid = approveUserSid;
    }

    public String getApproveUserName() {
        return approveUserName;
    }

    public void setApproveUserName(String approveUserName) {
        this.approveUserName = approveUserName;
    }

    public String getApproveUserCode() {
        return approveUserCode;
    }

    public void setApproveUserCode(String approveUserCode) {
        this.approveUserCode = approveUserCode;
    }

    public Date getEffectDate() {
        return effectDate;
    }

    public void setEffectDate(Date effectDate) {
        this.effectDate = effectDate;
    }

    public Long getApplyId() {
        return applyId;
    }

    public void setApplyId(Long applyId) {
        this.applyId = applyId;
    }

    public Long getApplyDetailId() {
        return applyDetailId;
    }

    public void setApplyDetailId(Long applyDetailId) {
        this.applyDetailId = applyDetailId;
    }

    public String getBrandName() {
        return brandName;
    }

    public void setBrandName(String brandName) {
        this.brandName = brandName;
    }

    public String getSourceId() {
        return sourceId;
    }

    public void setSourceId(String sourceId) {
        this.sourceId = sourceId;
    }

    public Integer getEnabled() {
        return enabled;
    }

    public void setEnabled(Integer enabled) {
        this.enabled = enabled;
    }

    public Integer getSequence() {
        return sequence;
    }

    public void setSequence(Integer sequence) {
        this.sequence = sequence;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
}
